
# TTS-STT Tools

`tts-stt-tools` is a Python package designed to simplify the process of text-to-speech (TTS) and speech-to-text (STT) conversions. With this package, you can easily convert text into speech using various TTS systems and manage audio files efficiently.

## Features

- **Text-to-Speech (TTS)**: Convert text into speech with customizable voice models.
- **Speech-to-Text (STT)**: Convert speech into text (if STT functionalities are included in future updates).
- **Audio Playback**: Play generated audio files on different operating systems.

## Installation

To install `tts-stt-tools`, you can use `pip`. The package can be installed from PyPI using the following command:

```bash
pip install tts-stt-tools
```

### Dependencies

- **mimic3-tts**: Required for TTS functionalities.
- **Other dependencies**: Listed in `requirements.txt`.

## Usage

Here's a quick guide on how to use the `tts-stt-tools` package.

### Example

1. **Import the package and initialize the TTS system:**

    ```python
    from tts_stt_tools import process_text_to_speech

    text = """
    Part three

    November 10–Present

    CHAPTER 14
    • Monday, November 10
    On Monday morning, Maxine is startled...
    """

    process_text_to_speech(text, voice_model='en_US/hifi-tts_low', filename='output.wav')
    ```

2. **The `process_text_to_speech` function will:**

    - Initialize the TTS system with the specified voice model.
    - Generate audio data from the given text.
    - Save the audio to a file.
    - Play the audio file using the appropriate system command.

## Documentation

For more detailed documentation on how to use each function and customize the TTS settings, please refer to the [documentation](https://pypi.org/project/tts-stt-tools/#description) (if available).

## Contributing

We welcome contributions to improve `tts-stt-tools`. If you want to contribute, please follow these steps:

1. Fork the repository.
2. Create a new branch for your feature or bugfix.
3. Make your changes and add tests if applicable.
4. Submit a pull request describing your changes.

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.

## Contact

For any questions or support, please contact [sainag268@gmail.com](sainag268@gmail.com).

---

Thank you for using `tts-stt-tools`! We hope it helps you with your text-to-speech and speech-to-text needs.
```
